@@ -2,7 +2,8 @@ test_that("distribution works", {
   data(survey, package = "MASS")
   set.seed(4565)
   columns <- c("Sex", "Age", "Smoke")
-  index <- design(pheno = survey[, columns], size_subset = 70,
+  nas <- c(137, 70)
+  index <- design(pheno = survey[-nas, columns], size_subset = 70,
                   iterations = 10)
   batches <- inspect(index, survey[, columns])
   expect_true(distribution(batches, "Sex"))
